PowerView Command Prompt.
=========================

Utility for basic control over your PowerView shades.

This tool makes use of prompt toolkit version 2 which is not officially released yet.

Go to:
https://github.com/jonathanslenders/python-prompt-toolkit

and do a manual install from the 2.0 branch.